/**
 * Copyright (c) 2015-2016  Telinc1
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */
package com.telinc1.nfls.field.array;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import com.telinc1.nfls.field.Field;

public class FieldBooleanArray extends Field {
    private boolean[] data;

    public FieldBooleanArray(){
        this.setData(null);
    }

    // Per the specification, the length of an array is 2 bytes, or a short.
    public FieldBooleanArray(short length){
        this(new boolean[length]);
    }

    public FieldBooleanArray(boolean[] data){
        this.setData(data);
    }

    public boolean[] getData(){
        return this.data;
    }

    public void setData(boolean[] data){
        this.data = data;
    }

    @Override
    public byte getType(){
        return Field.FIELD_BOOLEAN_ARRAY;
    }

    @Override
    public void writeToStream(DataOutputStream stream) throws IOException {
        stream.writeShort(this.getData().length);

        for(boolean value : this.getData()){
            stream.writeBoolean(value);
        }
    }

    @Override
    public void readFromStream(DataInputStream stream) throws IOException {
        boolean[] data = new boolean[stream.readShort()];

        for(int i = 0; i < data.length; i++){
            data[i] = stream.readBoolean();
        }

        this.setData(data);
    }
}
